==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/GridSelectedKeysChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridSelectedKeysChangedEventArgsDescription } from "./GridSelectedKeysChangedEventArgsDescription";
/**
 * @hidden
 */
export let GridSelectedKeysChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridSelectedKeysChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridSelectedKeysChangedEventArgsDescriptionMetadata.a == null) {
                GridSelectedKeysChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridSelectedKeysChangedEventArgsDescriptionMetadata.c(GridSelectedKeysChangedEventArgsDescriptionMetadata.a);
            }
            if (a.j(GridSelectedKeysChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(GridSelectedKeysChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("CurrentKeys", "Collection:PrimaryKeyValue:GridSelectedKeysCollection:PrimaryKeyValue");
            a.item("AddedKeys", "Collection:PrimaryKeyValue:GridSelectedKeysCollection:PrimaryKeyValue");
            a.item("RemovedKeys", "Collection:PrimaryKeyValue:GridSelectedKeysCollection:PrimaryKeyValue");
        }
        static d(a) {
            GridSelectedKeysChangedEventArgsDescriptionMetadata.b(a);
            a.aa("GridSelectedKeysChangedEventArgs", () => new GridSelectedKeysChangedEventArgsDescription());
            a.z("GridSelectedKeysChangedEventArgs", GridSelectedKeysChangedEventArgsDescriptionMetadata.a);
        }
    }
    GridSelectedKeysChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridSelectedKeysChangedEventArgsDescriptionMetadata, 'GridSelectedKeysChangedEventArgsDescriptionMetadata');
    GridSelectedKeysChangedEventArgsDescriptionMetadata.a = null;
    return GridSelectedKeysChangedEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/GridSelectedKeysChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { GridSelectedKeysChangedEventArgsDescription } from "./GridSelectedKeysChangedEventArgsDescription";
/**
 * @hidden
 */
export let GridSelectedKeysChangedEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class GridSelectedKeysChangedEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (GridSelectedKeysChangedEventArgsDescriptionMetadata.a == null) {
                GridSelectedKeysChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                GridSelectedKeysChangedEventArgsDescriptionMetadata.c(GridSelectedKeysChangedEventArgsDescriptionMetadata.a);
            }
            if (a.k(GridSelectedKeysChangedEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(GridSelectedKeysChangedEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("CurrentKeys", "Collection:PrimaryKeyValue:GridSelectedKeysCollection:PrimaryKeyValue");
            a.item("AddedKeys", "Collection:PrimaryKeyValue:GridSelectedKeysCollection:PrimaryKeyValue");
            a.item("RemovedKeys", "Collection:PrimaryKeyValue:GridSelectedKeysCollection:PrimaryKeyValue");
        }
        static d(a) {
            GridSelectedKeysChangedEventArgsDescriptionMetadata.b(a);
            a.ac("GridSelectedKeysChangedEventArgs", () => new GridSelectedKeysChangedEventArgsDescription());
            a.ab("GridSelectedKeysChangedEventArgs", GridSelectedKeysChangedEventArgsDescriptionMetadata.a);
        }
    }
    GridSelectedKeysChangedEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(GridSelectedKeysChangedEventArgsDescriptionMetadata, 'GridSelectedKeysChangedEventArgsDescriptionMetadata');
    GridSelectedKeysChangedEventArgsDescriptionMetadata.a = null;
    return GridSelectedKeysChangedEventArgsDescriptionMetadata;
})();
